@@ -38,5 +38,6 @@ class ViewsExtraction:
             sys.exit(0)
 
 if __name__ == '__main__':
-    ViewsExtraction().main()
+    views_extraction_inst = ViewsExtraction()
+    views_extraction_inst.main()
     print(Style.RESET_ALL)
